==> jc-1.4.0.tar.gz: soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h <==
// abstract class soot.util.SmallNumberedMap$SmallNumberedMapIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_
#define _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *);

// Virtual methods
extern jboolean _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *);
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*map;
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs {
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object {
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24SmallNumberedMapIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h <==
// abstract class soot.util.SmallNumberedMap$SmallNumberedMapIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_
#define _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method$seekNext$d7cfce2d63c0ff51(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$method_info$seekNext$d7cfce2d63c0ff51;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
	void	(*seekNext$d7cfce2d63c0ff51)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*map;
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs {
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs {
	jint	cur;
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$object {
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vtype _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24SmallNumberedMapIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24SmallNumberedMapIterator_H_ */
